@@ -1,6 +1,6 @@
 package Sub::Spec::Pod;
 BEGIN {
-  $Sub::Spec::Pod::VERSION = '0.04';
+  $Sub::Spec::Pod::VERSION = '0.05';
 }
 # ABSTRACT: Generate POD documentation for subs
 
@@ -46,8 +46,9 @@ sub _gen_sub_pod($;$) {
 
     my $args  = $sub_spec->{args} // {};
     my $rargs = $sub_spec->{required_args};
-    my $has_cat = grep { $_->[1]{arg_category} } values %$args;
     $args = { map {$_ => _parse_schema($args->{$_})} keys %$args };
+    my $has_cat = grep { $_->{attr_hashes}[0]{arg_category} }
+        values %$args;
 
     if (scalar keys %$args) {
         my $noted_star_req;
@@ -157,7 +158,7 @@ Sub::Spec::Pod - Generate POD documentation for subs
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
